@@ -35,7 +35,7 @@ sm_vgrid <- function(legends = TRUE, borders = TRUE) {
           axis.title.y = ggplot2::element_text(size = ggplot2::rel(.85), color = "black"),
           axis.title.x = ggplot2::element_text(size = ggplot2::rel(.85), color = "black", vjust = -1),
           axis.text.x = ggplot2::element_text(vjust = 0, size = ggplot2::rel(1.)),
-          panel.grid.major = ggplot2::element_line(size = 0.4),
+          panel.grid.major = ggplot2::element_line(linewidth = 0.4),
           plot.title = ggplot2::element_text(
             size = ggplot2::rel(.85),
             hjust = 0.5, face = "bold"
@@ -56,7 +56,7 @@ sm_vgrid <- function(legends = TRUE, borders = TRUE) {
           axis.title.y = ggplot2::element_text(size = ggplot2::rel(1.2), color = "black"),
           axis.title.x = ggplot2::element_text(size = ggplot2::rel(1.2), color = "black", vjust = -1),
           axis.text.x = ggplot2::element_text(vjust = 0),
-          panel.grid.major = ggplot2::element_line(size = 0.4),
+          panel.grid.major = ggplot2::element_line(linewidth = 0.4),
           plot.title = ggplot2::element_text(hjust = 0.5, face = "bold"),
           panel.grid.minor.x = ggplot2::element_blank(),
           panel.grid.minor.y = ggplot2::element_blank(),
@@ -77,7 +77,7 @@ sm_vgrid <- function(legends = TRUE, borders = TRUE) {
           axis.title.y = ggplot2::element_text(size = ggplot2::rel(.85), color = "black"),
           axis.title.x = ggplot2::element_text(size = ggplot2::rel(.85), color = "black", vjust = -1),
           axis.text.x = ggplot2::element_text(vjust = 0),
-          panel.grid.major = ggplot2::element_line(size = 0.4),
+          panel.grid.major = ggplot2::element_line(linewidth = 0.4),
           plot.title = ggplot2::element_text(size = ggplot2::rel(.85), hjust = 0.5, face = "bold"),
           panel.grid.minor.x = ggplot2::element_blank(),
           panel.grid.minor.y = ggplot2::element_blank(),
@@ -94,7 +94,7 @@ sm_vgrid <- function(legends = TRUE, borders = TRUE) {
           axis.title.y = ggplot2::element_text(size = ggplot2::rel(1.2), color = "black"),
           axis.title.x = ggplot2::element_text(size = ggplot2::rel(1.2), color = "black", vjust = -1),
           axis.text.x = ggplot2::element_text(vjust = 0),
-          panel.grid.major = ggplot2::element_line(size = 0.4),
+          panel.grid.major = ggplot2::element_line(linewidth = 0.4),
           plot.title = ggplot2::element_text(hjust = 0.5, face = "bold"),
           panel.grid.minor.x = ggplot2::element_blank(),
           panel.grid.minor.y = ggplot2::element_blank(),
